==> linuxconf-1.19.src.tar.gz: linuxconf-1.19/modules/wuftpd/wuftpd.pm <==
/* _dict.cc 01/02/1998 01.15.24 */
/* wuftpd.cc 12/12/1999 22.09.12 */
PUBLIC MODULE_wuftpd::MODULE_wuftpd (void);
PUBLIC void MODULE_wuftpd::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_wuftpd::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_wuftpd::dohtml (const char *);
PUBLIC void MODULE_wuftpd::usage (SSTRINGS&tb);
PUBLIC int MODULE_wuftpd::execmain (int argc, char *argv[]);
/* wuftpdedit.cc 27/06/2000 15.58.18 */
PUBLIC VIRTUAL_FTP::VIRTUAL_FTP (const char *_addr);
PUBLIC VIRTUAL_FTP::VIRTUAL_FTP (void);
PUBLIC VIRTUAL_FTP *VIRTUAL_FTPS::getitem (int no)const;
PUBLIC VIRTUAL_FTPS::VIRTUAL_FTPS (void);
PUBLIC void VIRTUAL_FTP::updateone (const SSTRING&val,
	 const char *keyw,
	 VIEWITEM *&item,
	 VIEWITEMS&items);
PUBLIC void VIRTUAL_FTPS::update (VIEWITEMS&items);
PUBLIC FTP_CTRL::FTP_CTRL (void);
PUBLIC void FTP_CTRL::setall (char val);
PRIVATE void WUFTPD::load (SSTRING&val,
	 VIEWITEMS&items,
	 const char *key);
PRIVATE void WUFTPD::load (int &val,
	 int defval,
	 VIEWITEMS&items,
	 const char *key1,
	 const char *key2);
PRIVATE void WUFTPD::store (SSTRING&val,
	 VIEWITEMS&items,
	 const char *key);
PRIVATE void WUFTPD::store (int val,
	 int defval,
	 VIEWITEMS&items,
	 const char *key1,
	 const char *key2);
PRIVATE void WUFTPD::setflags (const char *yes,
	 const char *members,
	 char &f_guest,
	 char &f_real,
	 char &f_anonymous);
PRIVATE void WUFTPD::settransfers (const char *members,
	 const char *type);
PUBLIC WUFTPD::WUFTPD (void);
PUBLIC int WUFTPD::write (void);
PRIVATE VIEWITEM *WUFTPD::locate_alloc (const char *key1,
	 const char *key2);
PRIVATE void WUFTPD::updatectrl (const char *oper,
	 char f_guest,
	 char f_real,
	 char f_anonymous);
PRIVATE void WUFTPD::updatetrans (void);
PUBLIC void WUFTPD::editaccess (void);
PUBLIC int VIRTUAL_FTP::createroot (void);
PUBLIC int VIRTUAL_FTP::edit (void);
PUBLIC void VIRTUAL_FTPS::edit (VIEWITEMS&items);
PUBLIC void WUFTPD::editvirtuals (void);
int FIXPERM_FTPD::check (bool, bool);
PUBLIC void WUFTPD::listperm (FIXPERM_SPECS&specs);
void FIXPERM_FTPD::list (FIXPERM_SPECS&specs);
PUBLIC VIRTUAL_FTP *WUFTPD::locatevhost (const char *vhost);
PUBLIC VIRTUAL_COMNG::VIRTUAL_COMNG (DICTIONARY&_dict);
PUBLIC void VIRTUAL_COMNG::setupdia (DIALOG&dia);
PUBLIC int VIRTUAL_COMNG::save (PRIVILEGE *priv);
PUBLIC int VIRTUAL_COMNG::validate (DIALOG&, int &nof);
PUBLIC int VIRTUAL_COMNG::deluser (PRIVILEGE *);
PUBLIC void WUFTPD::del (VIRTUAL_FTP *v);
PUBLIC void WUFTPD::add (VIRTUAL_FTP *v);

==> linuxconf-1.21.src.tar.gz: linuxconf-1.21/modules/wuftpd/wuftpd.pm <==
/* _dict.cc 01/02/1998 01.15.24 */
/* wuftpd.cc 28/08/2000 18.15.24 */
PUBLIC MODULE_wuftpd::MODULE_wuftpd (void);
PUBLIC void MODULE_wuftpd::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_wuftpd::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_wuftpd::dohtml (const char *);
PUBLIC void MODULE_wuftpd::usage (SSTRINGS&tb);
PUBLIC int MODULE_wuftpd::execmain (int argc, char *argv[], bool);
/* wuftpdedit.cc 27/06/2000 16.23.24 */
PUBLIC VIRTUAL_FTP::VIRTUAL_FTP (const char *_addr);
PUBLIC VIRTUAL_FTP::VIRTUAL_FTP (void);
PUBLIC VIRTUAL_FTP *VIRTUAL_FTPS::getitem (int no)const;
PUBLIC VIRTUAL_FTPS::VIRTUAL_FTPS (void);
PUBLIC void VIRTUAL_FTP::updateone (const SSTRING&val,
	 const char *keyw,
	 VIEWITEM *&item,
	 VIEWITEMS&items);
PUBLIC void VIRTUAL_FTPS::update (VIEWITEMS&items);
PUBLIC FTP_CTRL::FTP_CTRL (void);
PUBLIC void FTP_CTRL::setall (char val);
PRIVATE void WUFTPD::load (SSTRING&val,
	 VIEWITEMS&items,
	 const char *key);
PRIVATE void WUFTPD::load (int &val,
	 int defval,
	 VIEWITEMS&items,
	 const char *key1,
	 const char *key2);
PRIVATE void WUFTPD::store (SSTRING&val,
	 VIEWITEMS&items,
	 const char *key);
PRIVATE void WUFTPD::store (int val,
	 int defval,
	 VIEWITEMS&items,
	 const char *key1,
	 const char *key2);
PRIVATE void WUFTPD::setflags (const char *yes,
	 const char *members,
	 char &f_guest,
	 char &f_real,
	 char &f_anonymous);
PRIVATE void WUFTPD::settransfers (const char *members,
	 const char *type);
PUBLIC WUFTPD::WUFTPD (void);
PUBLIC int WUFTPD::write (void);
PRIVATE VIEWITEM *WUFTPD::locate_alloc (const char *key1,
	 const char *key2);
PRIVATE void WUFTPD::updatectrl (const char *oper,
	 char f_guest,
	 char f_real,
	 char f_anonymous);
PRIVATE void WUFTPD::updatetrans (void);
PUBLIC void WUFTPD::editaccess (void);
PUBLIC int VIRTUAL_FTP::createroot (void);
PUBLIC int VIRTUAL_FTP::edit (void);
PUBLIC void VIRTUAL_FTPS::edit (VIEWITEMS&items);
PUBLIC void WUFTPD::editvirtuals (void);
int FIXPERM_FTPD::check (bool, bool);
PUBLIC void WUFTPD::listperm (FIXPERM_SPECS&specs);
void FIXPERM_FTPD::list (FIXPERM_SPECS&specs);
PUBLIC VIRTUAL_FTP *WUFTPD::locatevhost (const char *vhost);
PUBLIC VIRTUAL_COMNG::VIRTUAL_COMNG (DICTIONARY&_dict);
PUBLIC void VIRTUAL_COMNG::setupdia (DIALOG&dia);
PUBLIC int VIRTUAL_COMNG::save (PRIVILEGE *priv);
PUBLIC int VIRTUAL_COMNG::validate (DIALOG&, int &nof);
PUBLIC int VIRTUAL_COMNG::deluser (PRIVILEGE *);
PUBLIC void WUFTPD::del (VIRTUAL_FTP *v);
PUBLIC void WUFTPD::add (VIRTUAL_FTP *v);
